# Cryptand.run VS Code Extension

[![Version](https://img.shields.io/badge/version-1.0.0-blue.svg)](https://github.com/cryptand/vscode-extension)
[![License](https://img.shields.io/badge/license-MIT-green.svg)](https://github.com/Iwasanity-dev/cryptand-vscode-extension/blob/HEAD/LICENSE)

Secure code sharing extension for VS Code that integrates with [Cryptand.run](https://cryptand.run) - share code snippets, secrets, and environment variables with end-to-end encryption directly from your IDE.

##  Features

- ** Secure Sharing**: End-to-end encryption for all shared content
- ** Smart Detection**: Automatic language detection for 25+ programming languages
- ** Quick Access**: Context menu integration and command palette support
- ** Configurable**: Customizable TTL, read limits, and API settings
- ** Universal**: Works with any text content - code, configs, secrets, logs

##  Installation

### From VS Code Marketplace
1. Open VS Code
2. Go to Extensions (Ctrl+Shift+X)
3. Search for "Cryptand.run"
4. Click Install

### From Release (.vsix)
1. Download the latest .vsix file from [Releases](https://github.com/cryptand/vscode-extension/releases)
2. Open VS Code
3. Press Ctrl+Shift+P and type "Extensions: Install from VSIX"
4. Select the downloaded file

##  Usage

### Quick Start
1. Select any text or code in VS Code
2. Right-click  "**Share Selection**"
3. Secure link is copied to clipboard automatically
4. Share the link with anyone - it's encrypted and expires automatically

### Available Commands
- **Share Selection** - Share selected text/code
- **Share Current File** - Share entire file content
- **Share as Environment Variables** - Special handling for .env files
- **Settings** - Configure extension preferences

### Context Menu
Right-click in any file to access sharing options directly from the context menu.

##  Configuration

Open VS Code Settings (Ctrl+,) and search for "Cryptand":

- cryptand.apiKey - Your API key (optional, for enhanced limits)
- cryptand.defaultTtl - Time-to-live in seconds (default: 3600)
- cryptand.defaultMaxReads - Maximum number of reads (default: 5)
- cryptand.autoDetectLanguage - Auto-detect programming language
- cryptand.apiUrl - API endpoint URL

##  Supported Languages

JavaScript, TypeScript, Python, Go, Rust, C/C++, C#, Java, PHP, Ruby, Shell/Bash, PowerShell, HTML, CSS, SCSS, YAML, JSON, XML, Dockerfile, and many more...

##  Security

- **Client-side encryption** before transmission
- **Automatic expiration** based on TTL settings
- **Read limits** to prevent unauthorized access
- **No server-side storage** of unencrypted content
- **Secure URL generation** with random tokens

##  Development

### Prerequisites
- Node.js 18+
- VS Code 1.74+

### Setup
`ash
git clone https://github.com/cryptand/vscode-extension.git
cd vscode-extension
npm install
`

### Build
`ash
npm run compile
`

### Debug
1. Open the project in VS Code
2. Press F5 to launch Extension Development Host
3. Test the extension in the new window

### Package
`ash
npm install -g @vscode/vsce
vsce package
`

##  Contributing

1. Fork the repository
2. Create your feature branch (git checkout -b feature/amazing-feature)
3. Commit your changes (git commit -m 'Add amazing feature')
4. Push to the branch (git push origin feature/amazing-feature)
5. Open a Pull Request

##  License

This project is licensed under the MIT License - see the [LICENSE](https://github.com/Iwasanity-dev/cryptand-vscode-extension/blob/HEAD/LICENSE) file for details.

##  Links

- [Cryptand.run Website](https://cryptand.run)
- [VS Code Marketplace](https://marketplace.visualstudio.com/items?itemName=cryptand.cryptand-run)
- [GitHub Repository](https://github.com/cryptand/vscode-extension)
- [Issue Tracker](https://github.com/cryptand/vscode-extension/issues)

##  Support

-  Email: support@cryptand.run
-  Issues: [GitHub Issues](https://github.com/cryptand/vscode-extension/issues)
-  Documentation: [Cryptand.run Docs](https://cryptand.run/docs)

---

Made with  for secure code sharing
