# Cryptand.run VS Code Extension - Usage Guide

## Overview
The Cryptand.run VS Code extension allows you to securely share code snippets, secrets, and environment variables directly from your IDE with end-to-end encryption.

## Installation

### From .vsix file
1. Download the `cryptand-run-1.0.0.vsix` file
2. Open VS Code
3. Go to Extensions (Ctrl+Shift+X)
4. Click the "..." menu → "Install from VSIX..."
5. Select the downloaded .vsix file

### From VS Code Marketplace (Coming Soon)
Search for "Cryptand.run" in the VS Code Extensions marketplace.

## Configuration

### 1. Set your API Key (Optional)
- Open VS Code Settings (Ctrl+,)
- Search for "Cryptand"
- Set your `cryptand.apiKey` if you have one
- Without an API key, you can still use the service with default limits

### 2. Configure Default Settings
Available settings:
- `cryptand.defaultTtl`: Time-to-live in seconds (default: 3600 = 1 hour)
- `cryptand.defaultMaxReads`: Maximum number of reads (default: 5)
- `cryptand.autoDetectLanguage`: Auto-detect programming language (default: true)
- `cryptand.apiUrl`: API endpoint (default: https://cryptand.run/api/v1/sharex)

## Usage

### 1. Share Selected Code
1. Select any text or code in the editor
2. Right-click → "Share Selection" (or use Command Palette: Ctrl+Shift+P → "Cryptand: Share Selection")
3. The extension will automatically detect the language and upload the content
4. A secure URL will be copied to your clipboard

### 2. Share Entire File
1. Open any file in the editor
2. Right-click in the editor → "Share Current File" (or use Command Palette)
3. The entire file content will be uploaded securely
4. A secure URL will be copied to your clipboard

### 3. Share Environment Variables
1. Open a .env file or any file containing environment variables
2. Right-click → "Share as Environment Variables"
3. The content will be uploaded with special handling for sensitive data
4. Recipients can access the variables securely

### 4. Access Extension Settings
- Use Command Palette (Ctrl+Shift+P) → "Cryptand: Settings"
- Configure API key, TTL, max reads, and other options

## Features

### Automatic Language Detection
The extension automatically detects the programming language based on:
- File extension (.js, .py, .go, etc.)
- VS Code language mode
- Content analysis for special files (Dockerfile, etc.)

### Supported Languages
- JavaScript/TypeScript (including React/JSX)
- Python
- Go
- Rust
- C/C++/C#
- Java
- PHP
- Ruby
- Shell/Bash/PowerShell
- HTML/CSS/SCSS
- YAML/JSON/XML
- And many more...

### Security Features
- End-to-end encryption
- Automatic expiration (TTL)
- Read limits
- No server-side storage of unencrypted content
- Secure URL generation

## Examples

### Sharing a Code Snippet
```javascript
// Select this code and use "Share Selection"
const apiKey = process.env.OPENAI_API_KEY;
console.log("API Key:", apiKey);
```

### Sharing Environment Variables
```bash
# Use "Share as Environment Variables" on .env files
DATABASE_URL=postgresql://user:pass@localhost:5432/db
API_KEY=secret_key_here
JWT_SECRET=your_jwt_secret
```

## Troubleshooting

### Common Issues

1. **Extension not found in Command Palette**
   - Make sure the extension is installed and enabled
   - Reload VS Code window (Ctrl+Shift+P → "Developer: Reload Window")

2. **Upload failed**
   - Check your internet connection
   - Verify API endpoint is accessible
   - Ensure content is not too large (max 100KB per upload)

3. **Language not detected correctly**
   - Manually save the file with the correct extension
   - Disable auto-detection in settings and specify language manually

### Getting Help
- Visit: https://cryptand.run
- GitHub Issues: https://github.com/cryptand/vscode-extension/issues
- Documentation: https://cryptand.run/docs

## Privacy & Security
- Your code is encrypted before transmission
- Cryptand.run uses client-side encryption
- Content is automatically deleted after expiration
- No logging of sensitive content on servers

## License
MIT License - see LICENSE file for details.
