# Cryptand Extension - Build and Package Script
Write-Host "================================" -ForegroundColor Cyan
Write-Host "Cryptand Extension - Build Script" -ForegroundColor Cyan
Write-Host "================================" -ForegroundColor Cyan

Write-Host ""
Write-Host "[1/4] Compiling TypeScript..." -ForegroundColor Yellow
npm run compile
if ($LASTEXITCODE -ne 0) {
    Write-Host "ERROR: Compilation failed!" -ForegroundColor Red
    Read-Host "Press Enter to exit"
    exit 1
}

Write-Host ""
Write-Host "[2/4] Reading current version..." -ForegroundColor Yellow
$packageJson = Get-Content "package.json" | ConvertFrom-Json
$version = $packageJson.version
Write-Host "Current version: $version" -ForegroundColor Green

Write-Host ""
Write-Host "[3/4] Creating VSIX package..." -ForegroundColor Yellow
vsce package
if ($LASTEXITCODE -ne 0) {
    Write-Host "ERROR: VSIX creation failed!" -ForegroundColor Red
    Read-Host "Press Enter to exit"
    exit 1
}

Write-Host ""
Write-Host "[4/4] Package created successfully!" -ForegroundColor Green
Write-Host "File: cryptand-run-$version.vsix" -ForegroundColor Green
Write-Host ""

Write-Host "================================" -ForegroundColor Cyan
Write-Host "Ready for distribution!" -ForegroundColor Cyan
Write-Host "================================" -ForegroundColor Cyan
Write-Host ""
Write-Host "To install manually:" -ForegroundColor White
Write-Host "1. Send cryptand-run-$version.vsix to your friends" -ForegroundColor Gray
Write-Host "2. In VS Code: Ctrl+Shift+P > 'Extensions: Install from VSIX...'" -ForegroundColor Gray
Write-Host "3. Select the VSIX file" -ForegroundColor Gray
Write-Host ""

Read-Host "Press Enter to exit"
