"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CryptandClient = void 0;
class CryptandClient {
    constructor(baseUrl = 'https://cryptand.run/api/v1/sharex') {
        this.baseUrl = baseUrl;
    }
    async uploadContent(request) {
        // Validate content size (100KB limit)
        if (new TextEncoder().encode(request.content).length > 100000) {
            throw new Error('Content exceeds 100KB limit');
        }
        // Validate TTL (max 30 days)
        if (request.ttl > 30 * 24 * 60 * 60) {
            throw new Error('TTL cannot exceed 30 days');
        }
        // Validate maxReads (max 100)
        if (request.maxReads > 100) {
            throw new Error('Max reads cannot exceed 100');
        }
        try {
            const response = await fetch(this.baseUrl, {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json',
                    'User-Agent': 'Cryptand-VSCode-Extension/1.0.0'
                },
                body: JSON.stringify(request)
            });
            if (!response.ok) {
                const errorData = await response.json().catch(() => ({}));
                const errorMessage = errorData.error || `HTTP ${response.status}: ${response.statusText}`;
                throw new Error(errorMessage);
            }
            const result = await response.json();
            if (!result.success) {
                throw new Error(result.message || 'Upload failed');
            }
            return result;
        }
        catch (error) {
            if (error instanceof TypeError && error.message.includes('fetch')) {
                throw new Error('Network error: Unable to connect to Cryptand.run. Please check your internet connection.');
            }
            throw error;
        }
    }
    async validateApiKey(apiKey) {
        try {
            const testResponse = await fetch(this.baseUrl, {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json',
                    'User-Agent': 'Cryptand-VSCode-Extension/1.0.0'
                },
                body: JSON.stringify({
                    content: 'test',
                    apiKey,
                    language: 'plaintext',
                    ttl: 60,
                    maxReads: 1
                })
            }); // If we get a 401, the API key is invalid
            if (testResponse.status === 401) {
                return false;
            }
            return true;
        }
        catch {
            return false;
        }
    }
}
exports.CryptandClient = CryptandClient;
//# sourceMappingURL=cryptandClient.js.map