"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.deactivate = exports.activate = void 0;
const vscode = __importStar(require("vscode"));
const cryptandClient_1 = require("./cryptandClient");
const languageDetector_1 = require("./languageDetector");
function activate(context) {
    console.log('Cryptand.run extension is now active!');
    const client = new cryptandClient_1.CryptandClient();
    const languageDetector = new languageDetector_1.LanguageDetector();
    // Share Selection Command
    const shareSelection = vscode.commands.registerCommand('cryptand.shareSelection', async () => {
        const editor = vscode.window.activeTextEditor;
        if (!editor) {
            vscode.window.showErrorMessage('No active editor found');
            return;
        }
        const selection = editor.selection;
        if (selection.isEmpty) {
            vscode.window.showErrorMessage('No text selected');
            return;
        }
        const selectedText = editor.document.getText(selection);
        const language = languageDetector.detectFromDocument(editor.document);
        await shareContent(selectedText, language, 'Selection');
    });
    // Share Current File Command
    const shareFile = vscode.commands.registerCommand('cryptand.shareFile', async () => {
        const editor = vscode.window.activeTextEditor;
        if (!editor) {
            vscode.window.showErrorMessage('No active editor found');
            return;
        }
        const document = editor.document;
        const content = document.getText();
        const language = languageDetector.detectFromDocument(document);
        const fileName = document.fileName.split(/[\\/]/).pop() || 'file';
        await shareContent(content, language, fileName);
    });
    // Share as Environment Variables Command
    const shareEnvFile = vscode.commands.registerCommand('cryptand.shareEnvFile', async () => {
        const editor = vscode.window.activeTextEditor;
        if (!editor) {
            vscode.window.showErrorMessage('No active editor found');
            return;
        }
        const content = editor.document.getText();
        await shareContent(content, 'bash', 'Environment Variables', true);
    });
    // Settings Command
    const settings = vscode.commands.registerCommand('cryptand.settings', () => {
        vscode.commands.executeCommand('workbench.action.openSettings', 'cryptand');
    });
    async function shareContent(content, language, type, isEnv = false) {
        try {
            // Validate content
            if (!content.trim()) {
                vscode.window.showErrorMessage('Content is empty');
                return;
            }
            // Check API key
            const config = vscode.workspace.getConfiguration('cryptand');
            const apiKey = config.get('apiKey');
            if (!apiKey) {
                const action = await vscode.window.showErrorMessage('Cryptand.run API key not configured', 'Open Settings');
                if (action === 'Open Settings') {
                    vscode.commands.executeCommand('cryptand.settings');
                }
                return;
            }
            // Show progress
            await vscode.window.withProgress({
                location: vscode.ProgressLocation.Notification,
                title: `Uploading ${type} to Cryptand.run...`,
                cancellable: false
            }, async (progress) => {
                progress.report({ increment: 0 });
                try {
                    const ttl = config.get('defaultTtl') || 3600;
                    const maxReads = config.get('defaultMaxReads') || 5;
                    progress.report({ increment: 50, message: 'Encrypting...' });
                    const result = await client.uploadContent({
                        content,
                        apiKey,
                        language,
                        ttl,
                        maxReads
                    });
                    progress.report({ increment: 100, message: 'Complete!' });
                    // Show success message with actions
                    const action = await vscode.window.showInformationMessage(`${type} shared successfully!`, 'Copy URL', 'Open in Browser');
                    if (action === 'Copy URL') {
                        await vscode.env.clipboard.writeText(result.url);
                        vscode.window.showInformationMessage('URL copied to clipboard!');
                    }
                    else if (action === 'Open in Browser') {
                        vscode.env.openExternal(vscode.Uri.parse(result.url));
                    }
                    // Show details in output channel
                    const outputChannel = vscode.window.createOutputChannel('Cryptand.run');
                    outputChannel.appendLine(`${new Date().toISOString()} - ${type} shared:`);
                    outputChannel.appendLine(`URL: ${result.url}`);
                    outputChannel.appendLine(`Language: ${result.language}`);
                    outputChannel.appendLine(`TTL: ${ttl} seconds`);
                    outputChannel.appendLine(`Max Reads: ${maxReads}`);
                    outputChannel.appendLine(`API Key: ${result.apiKey?.name || 'Unknown'}`);
                    outputChannel.appendLine('---');
                }
                catch (error) {
                    throw error;
                }
            });
        }
        catch (error) {
            const errorMessage = error instanceof Error ? error.message : 'Unknown error occurred';
            vscode.window.showErrorMessage(`Failed to share content: ${errorMessage}`);
            console.error('Cryptand upload error:', error);
        }
    }
    context.subscriptions.push(shareSelection, shareFile, shareEnvFile, settings);
}
exports.activate = activate;
function deactivate() {
    console.log('Cryptand.run extension deactivated');
}
exports.deactivate = deactivate;
//# sourceMappingURL=extension.js.map